Conf

Struct Conf 

pub struct Conf {
    pub strip_brackets: bool,
    pub vulgar_fracs: bool,
    pub script_fracs: bool,
    pub skin_tone: SkinTone,
    pub block: bool,
}
Configuration for unicode rendering of asciimath

Fields

strip_brackets: bool

If true, this will strip unnecessary parenthesis in some contexts

vulgar_fracs: bool

If true, this will try to render fractions as vulgar fractions

script_fracs: bool

If true, this will try to render fractions using super- and sub-scripts

skin_tone: SkinTone

Default skin tone for emojis

block: bool

If true, render as multi-line 2D block (stacked fractions, vertical scripts, matrix grids)

Implementations

Source

impl Conf

pub fn parse(self, inp: &str) -> Asciimath<'_>

Parse an asciimath string into an Asciimath value that implements fmt::Display