pub struct Conf {
pub strip_brackets: bool,
pub vulgar_fracs: bool,
pub script_fracs: bool,
pub skin_tone: SkinTone,
pub block: bool,
}Expand description
Configuration for unicode rendering of asciimath
Fields
strip_brackets: boolIf true, this will strip unnecessary parenthesis in some contexts
vulgar_fracs: boolIf true, this will try to render fractions as vulgar fractions
script_fracs: boolIf true, this will try to render fractions using super- and sub-scripts
skin_tone: SkinToneDefault skin tone for emojis
block: boolIf true, render as multi-line 2D block (stacked fractions, vertical scripts, matrix grids)
Implementations